#!/bin/bash

# copyright for this file is GPLv3+ belonging to Jon Bendtsen jonbendtsen@jonix.dk
# copyright for the mac_audit application does not belong to me (Jon),
# but to someone else, see this url for a little more information
# http://www.open-audit.org/phpBB3/viewtopic.php?f=5&t=3678&p=16659

# this script will install open_mac_audit into ~/Library/open_mac_audit
# and add a cronjob into your users crontab which runs
# open_mac_audit.sh once every hour. open_mac_audit.sh contains
# code that will actually only post data to the OpenAudIT server
# once every 24 hours to prevent filling up the database.
# we run it every our locally because what if the computer just
# happened to be sleeping when it was supposed to run it?

# INSTALLING
echo "This script will install open_mac_audit client into ~/Library/open_mac_audit"
echo "----------------------------------------------------------------------------"
echo .
echo .
mkdir -p ~/Library/open_mac_audit
working_directory=$(echo $0 | sed -e "s/\(.*\)\/.*$/\1/")
cp -i "$working_directory/mac_audit" ~/Library/open_mac_audit/
cp -i "$working_directory/open_mac_audit.command" ~/Library/open_mac_audit/
cp -i "$working_directory/servers.cfg" ~/Library/open_mac_audit/

echo .
echo .

# Running open mac audit
echo "Running open_mac_audit.command"
~/Library/open_mac_audit/open_mac_audit.command 


echo .
echo .


# ADDING THE CRONTAB
crontab -l | grep -q open_mac_audit.command
exit_code=$?
if [ 0 -ne "$exit_code" ]; then
  echo "Adding crontab for you to run ~/Library/open_mac_audit/open_mac_audit.command hourly"
  (crontab -l ; echo "@hourly ~/Library/open_mac_audit/open_mac_audit.command") | crontab
  exit_code=$?
  if [ 0 -ne "$exit_code" ]; then
    echo -n "WARNING! Failed to preserve your current crontab, you will have to manually add"
    echo "the next line to your crontab using the command crontab -e in Terminal.app"
    echo "@hourly ~/Library/open_mac_audit/open_mac_audit.command"
    sleep 1000000
    exit 1
  fi
fi

echo .
sleep 1
echo .
sleep 1
echo .
sleep 1
echo .
sleep 1
echo .
sleep 1
echo .
sleep 1
echo .
sleep 1

echo "FINISHED, YOU MAY CLOSE THIS WINDOW"
